Derive Macro FromPg

#[derive(FromPg)]
{
    // Attributes available to this derive:
    #[frompg]
}
For a type using the frompg macro, you can write #[frompg(from = T, func = F)] above a field. This retrieves any valid attributes from a field, and can return an error.